==> italent-task-operate-area-5.1.5.tgz: package/lib/component/common/pullScreen/component/chargeUserSelector/style.js <==
import styled, { css } from 'styled-components';
var font =
/*#__PURE__*/
css(["font-family:\"PingFangSC-Regular\",\"Microsoft YaHei\";"]);
var UserWrap =
/*#__PURE__*/
styled.div(["display:", ";.__common-user-avatar-wrap{vertical-align:middle;}"], function (props) {
  return props.show ? 'block' : 'none';
});
var textDot =
/*#__PURE__*/
css(["text-overflow:ellipsis;white-space:nowrap;overflow:hidden;"]);
var infoText =
/*#__PURE__*/
css(["font-size:12px;line-height:20px;"]);
var UserTitle =
/*#__PURE__*/
styled.div(["", " ", " margin-bottom:4px;color:#83898F;"], font, infoText);
var SearchWrap =
/*#__PURE__*/
styled.div(["width:calc(100% - 20px);"]);
var UserPopWrap =
/*#__PURE__*/
styled.div(["position:fixed;z-index:9;width:20px;right:20px;bottom:0px;height:calc( 100% - 360px );min-height:472px;"]); // UserList

var UserList =
/*#__PURE__*/
styled.ul(["padding:0px;margin:0px;width:calc(100% - 20px );"]);
var UserItem =
/*#__PURE__*/
styled.li(["height:48px;padding-left:10px;box-sizing:border-box;list-style:none;line-height:48px;position:relative;:hover{background-color:rgba(133,194,255,0.1);}"]);
var UserInfo =
/*#__PURE__*/
styled.span(["width:calc(100% - 76px);display:inline-block;vertical-align:middle;margin-left:10px;"]);
var UserName =
/*#__PURE__*/
styled.div(["", " ", " ", " color:#0E1114;"], textDot, font, infoText);
var UserEmail =
/*#__PURE__*/
styled.div(["", " ", " ", " color:#83898F;"], textDot, font, infoText);
var RemoveUser =
/*#__PURE__*/
styled.span(["display:inline-block;width:14px;height:14px;font-size:14px;color:#BFC3C7;position:absolute;right:12px;top:18px;&:hover{color:#FF475A;}"]);
export { UserWrap, UserTitle, SearchWrap, UserPopWrap, UserList, UserItem, UserInfo, UserName, UserEmail, RemoveUser };

==> italent-task-operate-area-5.1.8.tgz: package/lib/component/common/pullScreen/component/chargeUserSelector/style.js <==
import styled, { css } from 'styled-components';
var font =
/*#__PURE__*/
css(["font-family:\"PingFangSC-Regular\",\"Microsoft YaHei\";"]);
var UserWrap =
/*#__PURE__*/
styled.div(["display:", ";.__common-user-avatar-wrap{vertical-align:middle;}"], function (props) {
  return props.show ? 'block' : 'none';
});
var textDot =
/*#__PURE__*/
css(["text-overflow:ellipsis;white-space:nowrap;overflow:hidden;"]);
var infoText =
/*#__PURE__*/
css(["font-size:12px;line-height:20px;"]);
var UserTitle =
/*#__PURE__*/
styled.div(["", " ", " margin-bottom:4px;color:#83898F;"], font, infoText);
var SearchWrap =
/*#__PURE__*/
styled.div(["width:calc(100% - 20px);.base-search-component .base-search-input .base-search-input-default{padding:0px;}.base-search-component .base-search-input .base-search-input-default .base-search-input-icon{padding-bottom:0px;margin-top:0px;margin-left:1px;padding-left:0px;}.base-search-component .base-search-input-active div.base-search-input-default .base-search-input-icon{margin-left:1px;margin-top:5px;padding-left:0px;padding-top:0px;}"]);
var UserPopWrap =
/*#__PURE__*/
styled.div(["position:fixed;z-index:9;width:20px;right:20px;bottom:0px;height:calc( 100% - 360px );min-height:472px;"]); // UserList

var UserList =
/*#__PURE__*/
styled.ul(["padding:0px;margin:0px;width:calc(100% - 20px );"]);
var UserItem =
/*#__PURE__*/
styled.li(["height:48px;padding-left:10px;box-sizing:border-box;list-style:none;line-height:48px;position:relative;:hover{background-color:rgba(133,194,255,0.1);}"]);
var UserInfo =
/*#__PURE__*/
styled.span(["width:calc(100% - 76px);display:inline-block;vertical-align:middle;margin-left:10px;"]);
var UserName =
/*#__PURE__*/
styled.div(["", " ", " ", " color:#0E1114;"], textDot, font, infoText);
var UserEmail =
/*#__PURE__*/
styled.div(["", " ", " ", " color:#83898F;"], textDot, font, infoText);
var RemoveUser =
/*#__PURE__*/
styled.span(["display:inline-block;width:14px;height:14px;font-size:14px;color:#BFC3C7;position:absolute;right:12px;top:18px;&:hover{color:#FF475A;}"]);
export { UserWrap, UserTitle, SearchWrap, UserPopWrap, UserList, UserItem, UserInfo, UserName, UserEmail, RemoveUser };
